@@ -1,7 +1,7 @@
 /*
- *  $Id: acconfig.h,v 1.3 1999/05/26 17:09:55 sbooth Exp $
+ *  $Id: acconfig.h,v 1.6 2000/11/15 06:31:40 sbooth Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999 Stephen F. Booth
+ *  Copyright (C) 1996, 1997, 1998, 1999, 2000 Stephen F. Booth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 /* Version of package. */
 #undef VERSION
 
-/* System Cgicc was configured for */
+/* System cgicc was configured for */
 #define HOST ""
 
-/* Whether to use namespaces */
-#define USE_NAMESPACES 1
+/* Whether to enable debug logging */
+#undef DEBUG
