@@ -1,7 +1,7 @@
 /*
- *  $Id: test.cpp,v 1.5 1999/08/17 17:16:11 sbooth Exp $
+ *  $Id: test.cpp,v 1.14 2000/10/17 00:22:54 sbooth Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999 Stephen F. Booth
+ *  Copyright (C) 1996, 1997, 1998, 1999, 2000 Stephen F. Booth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
 // To use logging, the variable gLogFile MUST be defined, and it _must_
 // be an ofstream
 #if DEBUG
-  STDNS ofstream gLogFile( "/change_this_path/Cgicc.log", STDNS ios::app );
+  STDNS ofstream gLogFile( "/change_this_path/cgicc.log", STDNS ios::app );
 #endif
 
 #if CGICC_USE_NAMESPACES
@@ -48,6 +48,7 @@
   using namespace cgicc;
 #else
 #  define div div_
+#  define link link_
 #  define select select_
 #endif
 
@@ -55,12 +56,11 @@
 void dumpEnvironment(const CgiEnvironment& env);
 void dumpList(const Cgicc& formData);
 void showForm(const Cgicc& formData);
-void showFile(const Cgicc& formData);
 
 // Main Street, USA
 int
-main(int argc, 
-     char **argv)
+main(int /*argc*/, 
+     char ** /*argv*/)
 {
   try {
 #if HAVE_GETTIMEOFDAY
@@ -111,7 +111,7 @@ main(int argc,
 
     cout << comment() << style() << endl;
 
-    cout << title() << "GNU Cgicc v" << cgi.getVersion() << " Test Results" 
+    cout << title() << "GNU cgicc v" << cgi.getVersion() << " Test Results" 
 	 << title() << endl;
     cout << meta().set("name", "author").set("content", "Stephen F. Booth") 
 	 << endl;
@@ -121,16 +121,16 @@ main(int argc,
     // Start the HTML body
     cout << body() << endl;
 
-    cout << h1() << "GNU Cgi" << span("cc").set("class","red")
+    cout << h1() << "GNU cgi" << span("cc").set("class","red")
 	 << " v"<< cgi.getVersion() << " Test Results" << h1() << endl;
     
     // Get a pointer to the environment
     const CgiEnvironment& env = cgi.getEnvironment();
     
     // Generic thank you message
-    cout << comment() << "This page generated by Cgicc for "
+    cout << comment() << "This page generated by cgicc for "
 	 << env.getRemoteHost() << comment() << endl;
-    cout << h4() << "Thanks for using Cgi" << span("cc").set("class", "red") 
+    cout << h4() << "Thanks for using cgi" << span("cc").set("class", "red") 
 	 << ", " << env.getRemoteHost() 
 	 << '(' << env.getRemoteAddr() << ")!" << h4() << endl;  
     
@@ -175,24 +175,18 @@ main(int argc,
     if(cgi.queryCheckbox("showForm"))
       showForm(cgi);
 
-    // If the user requested information on the uploaded file,
-    // create a simple table showing the information
-    // Disabled for demo
-    if(cgi.queryCheckbox("showFile"))
-      showFile(cgi);
-
     // Now print out a footer with some fun info
     cout << p() << CGICCNS div().set("align","center");
     cout << a("Back to form").set("href", cgi.getEnvironment().getReferrer()) 
 	 << endl;
     cout << CGICCNS div() << br() << hr(set("class","half")) << endl;
     
-    // Information on Cgicc
+    // Information on cgicc
     cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
-    cout << "GNU Cgi" << span("cc").set("class","red") << " v";
+    cout << "GNU cgi" << span("cc").set("class","red") << " v";
     cout << cgi.getVersion();
     cout << " by " << a("Stephen F. Booth")
-                       .set("href", "http://www.lmi.net/~sbooth/") 
+                       .set("href", "http://home.earthlink.net/~sfbooth/") 
 	 << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime();
     cout << " on " << cgi.getCompileDate() << br() << endl;
@@ -260,14 +254,14 @@ main(int argc,
 
     cout << comment() << style() << endl;
 
-    cout << title("GNU Cgicc exception") << endl;
+    cout << title("GNU cgicc exception") << endl;
     cout << meta().set("name", "author")
 		  .set("content", "Stephen F. Booth") << endl;
     cout << head() << endl;
     
     cout << body() << endl;
     
-    cout << h1() << "GNU Cgi" << span("cc", set("class","red"))
+    cout << h1() << "GNU cgi" << span("cc", set("class","red"))
 	 << " caught an exception" << h1() << endl; 
   
     cout << CGICCNS div().set("align","center").set("class","notice") << endl;
@@ -326,7 +320,7 @@ dumpEnvironment(const CgiEnvironment& env)
        << tr() << endl;
   cout << tr() << td("Remote Host").set("class","title") 
        << td(env.getRemoteHost()).set("class","data") << tr() << endl;
-  cout << tr() << td("Remote Setress").set("class","title") 
+  cout << tr() << td("Remote Address").set("class","title") 
        << td(env.getRemoteAddr()).set("class","data") << tr() << endl;
   cout << tr() << td("Authorization Type").set("class","title") 
        << td(env.getAuthType()).set("class","data") << tr() << endl;
@@ -351,6 +345,9 @@ dumpEnvironment(const CgiEnvironment& env)
   cout << tr() << td("Server Port").set("class","title") 
        << td().set("class","data") << env.getServerPort() 
        << td() << tr() << endl;
+  cout << tr() << td("HTTPS").set("class","title")
+       << td().set("class","data") << (env.usingHTTPS() ? "true" : "false")
+       << td() << tr() << endl;
   cout << tr() << td("Redirect Request").set("class","title") 
        << td(env.getRedirectRequest()).set("class","data") << tr() << endl;
   cout << tr() << td("Redirect URL").set("class","title") 
@@ -380,7 +377,7 @@ dumpList(const Cgicc& formData)
        << td("Element Value") << tr() << endl;
   
   // Iterate through the vector, and print out each value
-  STDNS vector<FormEntry>::const_iterator iter;
+  const_form_iterator iter;
   for(iter = formData.getElements().begin(); 
       iter != formData.getElements().end(); 
       ++iter) {
@@ -401,14 +398,14 @@ showForm(const Cgicc& formData)
   cout << CGICCNS div().set("class","notice") << endl;
 
   //getElement
-  STDNS vector<FormEntry>::const_iterator name = formData.getElement("name");
+  const_form_iterator name = formData.getElement("name");
   if(name != (*formData).end() && ! name->isEmpty())
     cout << "Your name is " << **name << '.' << br() << endl;
   else
     cout << "You don't have a name." << br() << endl;
 
   // getElement and getDoubleValue
-  STDNS vector<FormEntry>::const_iterator salary = formData.getElement("bucks");
+  const_form_iterator salary = formData.getElement("bucks");
   if(salary != (*formData).end() && ! salary->isEmpty())
     cout << "You make " << (*salary).getDoubleValue(80, 120) 
 	 << " million dollars." << br() << endl;
@@ -416,7 +413,7 @@ showForm(const Cgicc& formData)
     cout << "You don't have a salary." << br() << endl;
 
   // getElement and getIntegerValue
-  STDNS vector<FormEntry>::const_iterator hours = formData.getElement("time");
+  const_form_iterator hours = formData.getElement("time");
   if(hours != (*formData).end() && ! (*hours).isEmpty())
     cout << "You've wasted " << (*hours).getIntegerValue() 
 	 << " hours on the web." << br() << endl;
@@ -424,7 +421,7 @@ showForm(const Cgicc& formData)
     cout << "You haven't wasted any time on the web." << br() << endl;
 
   // getElement and getStrippedValue
-  STDNS vector<FormEntry>::const_iterator sheep = formData.getElement("sheep");
+  const_form_iterator sheep = formData.getElement("sheep");
   if(sheep != (*formData).end() && ! (*sheep).isEmpty()) {
     STDNS string temp = (*sheep).getStrippedValue();
     cout << "Your thoughts about sheep cloning: " << temp << br() << endl;
@@ -456,13 +453,13 @@ showForm(const Cgicc& formData)
     cout << "You don't like ice cream!?" << br() << endl;
   
   // getElement
-  STDNS vector<FormEntry>::const_iterator hair = formData.getElement("hair");
+  const_form_iterator hair = formData.getElement("hair");
   if(hair != (*formData).end())
     cout << "Your hair is " << **hair << '.' << br() << endl;
   else
     cout << "You don't have any hair." << br() << endl;
   
-  STDNS vector<FormEntry>::const_iterator vote = formData.getElement("vote");
+  const_form_iterator vote = formData.getElement("vote");
   if(vote != (*formData).end())
     cout << "You voted for " << **vote << '.' << br() << endl;
   else
@@ -487,51 +484,3 @@ showForm(const Cgicc& formData)
   
   cout << CGICCNS div() << endl;
 }
-
-// Show the uploaded file
-// This will work if you uncomment the appropriate lines in testform.html
-void
-showFile(const Cgicc& formData) 
-{
-  cout << h2("File Uploaded via FormFile") << endl;
-  
-  STDNS vector<FormFile>::const_iterator file;
-  file = formData.getFile("userfile");
-				
-  if(file != formData.getFiles().end()) {
-    cout << CGICCNS div().set("align","center") << endl;
-    
-    cout << table().set("border","0").set("rules","none").set("frame","void")
-		   .set("cellspacing","2").set("cellpadding","2")
-		   .set("class","cgi") << endl;
-    cout << colgroup().set("span","2") << endl;
-    cout << col().set("align","center").set("class","title").set("span","1") 
-	 << endl;
-    cout << col().set("align","left").set("class","data").set("span","1") 
-	 << endl;
-    cout << colgroup() << endl;
-    
-    cout << tr() << td("Name").set("class","title")
-	 << td((*file).getName()).set("class","data") << tr() << endl;
-
-    cout << tr() << td("Data Type").set("class","title")
-	 << td((*file).getDataType()).set("class","data") << tr() << endl;
-    
-    cout << tr() << td("Filename").set("class","title") 
-	 << td((*file).getFilename()).set("class","data") << tr() << endl;
-    cout << tr() << td("Data Length").set("class","title") 
-	 << td().set("class","data") << (*file).getDataLength() 
-	 << td() << tr() << endl;
-    
-    cout << tr() << td("File Data").set("class","title")
-	 << td().set("class","data") << pre();
-    (*file).writeToStream(cout);
-    cout << pre() << td() << tr() << endl;
-    
-    cout << table() << CGICCNS div() << endl;
-  }
-  else {
-    cout << p() << CGICCNS div().set("class", "notice") << endl;
-    cout << "No file was uploaded." << endl << CGICCNS div() << p() << endl;
-  }
-}
